==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/document_financeiro/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2010 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Document Management System-SIG',
    'version': '7.0.21.12.14',
    'category': 'Knowledge Management',
    'description': """
Complementa o modulo Document.
==============================
    * Cria menus para pessoa, cliente, fornecedor e project_br
""",
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['document', 'financeiro', 'project_br'],
    'license': 'Other proprietary',
    'data': [
        "dados/document_data.xml",
        'inherit/base/ir_attachment_view.xml',
        "inherit/base/document_view.xml",
        'views/actions.xml',
    ],
    'test': [],
    'js': [],
    'installable': True,
    'application': False,
    'auto_install': False,
    'images': [],
}

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/document_financeiro/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2010 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Document Management System-SIG',
    'version': '7.0.2310.2',
    'category': 'Knowledge Management',
    'description': """
Complementa o modulo Document.
==============================
    * Cria menus para pessoa, cliente, fornecedor e project_br
""",
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['document', 'financeiro', 'project_br'],
    'license': 'Other proprietary',
    'data': [
        "dados/document_data.xml",
        'inherit/base/ir_attachment_view.xml',
        "inherit/base/document_view.xml",
        'views/actions.xml',
    ],
    'test': [],
    'js': [],
    'installable': True,
    'application': False,
    'auto_install': False,
    'images': [],
}

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
